==> haskell-yesod-static-1.5.0.3-25-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.0.3
id: yesod-static-1.5.0.3-663be57bdaf5d669c0233bf144f75855
key: yesod_CtqlnyPGHuuKRZqEmtCoPy
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
hs-libraries: HSyesod-static-1.5.0.3-CtqlnyPGHuuKRZqEmtCoPy
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
    cryptohash-conduit-0.1.1-6b607828fd72a263de0a99a243d6077b
    css-text-0.1.2.1-d1e175085ae55e4b9482a244b4d6aeb3
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    hjsmin-0.1.5.3-408bbfe5511e989538833527e5c06f0a
    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
    wai-app-static-3.1.4.1-44f6dcf8d731760c41ac34c914e6b5b3
    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.5.0.3-26-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-static/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.0.3
id: yesod-static-1.5.0.3-977ed873df8c052fba68caa59b4d9941
key: yesod_2ZcAW8XxySb51EwNqZG6Z5
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-static-1.5.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-static-1.5.0.3
hs-libraries: HSyesod-static-1.5.0.3-2ZcAW8XxySb51EwNqZG6Z5
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
    cryptohash-conduit-0.1.1-6b607828fd72a263de0a99a243d6077b
    css-text-0.1.2.1-d1e175085ae55e4b9482a244b4d6aeb3
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    hjsmin-0.1.5.3-408bbfe5511e989538833527e5c06f0a
    http-types-0.9-181a315082d46c3ed5dffe75933f2447
    mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    wai-3.2.0-e103f0650175c07d97df46c35b6789e8
    wai-app-static-3.1.4.1-10c73faf0f98f74ec9ef1f8ee47d59ad
    yesod-core-1.4.19-76e562217b8c2dec9e581394dccca7d9
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
